AccelerationStructureBuildRangeInfo

Struct AccelerationStructureBuildRangeInfo 

#[repr(C)]
pub struct AccelerationStructureBuildRangeInfo { pub primitive_count: u32, pub primitive_offset: u32, pub first_vertex: u32, pub transform_offset: u32, }
Counts and offsets for an acceleration structure build operation.

Fields

primitive_count: u32

The number of primitives.

The default value is 0.

primitive_offset: u32

The offset (in bytes) into the buffer holding geometry data, to where the first primitive is stored.

The default value is 0.

first_vertex: u32

The index of the first vertex to build from.

This is used only for triangle geometries.

The default value is 0.

transform_offset: u32

The offset (in bytes) into the buffer holding transform matrices, to where the matrix is stored.

This is used only for triangle geometries.

The default value is 0.