#[non_exhaustive]pub enum BufferMemory {
Normal(ResourceMemory),
Sparse,
External,
}Expand description
The type of backing memory that a buffer can have.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal(ResourceMemory)
The buffer is backed by normal memory, bound with bind_memory.
Sparse
The buffer is backed by sparse memory, bound with bind_sparse.
External
The buffer is backed by memory not managed by vulkano.