Module allocator

Module allocator 

Traits and types for managing the allocation of command buffers and command pools.

In Vulkano, creating a command buffer requires passing an implementation of the CommandBufferAllocator trait. You can implement this trait yourself, or use the Vulkano-provided StandardCommandBufferAllocator.

Structs

AllocationHandle
An opaque handle identifying an allocation inside an allocator.
CommandBufferAlloc
An allocation made using a command buffer allocator.
StandardCommandBufferAllocator
Standard implementation of a command buffer allocator.
StandardCommandBufferAllocatorCreateInfo
Parameters to create a new StandardCommandBufferAllocator.

Enums

ResetCommandPoolError
Error that can be returned when resetting a CommandPool.

Traits

CommandBufferAllocator
Types that manage the memory of command buffers.