pub struct CommandBufferAlloc {
pub inner: CommandPoolAlloc,
pub pool: Arc<CommandPool>,
pub handle: AllocationHandle,
}Expand description
An allocation made using a command buffer allocator.
Fields
inner: CommandPoolAllocThe internal object that contains the command buffer.
pool: Arc<CommandPool>The command pool that the command buffer was allocated from.
Using this for anything other than looking at the pool’s metadata will lead to a Bad TimeTM.
handle: AllocationHandleAn opaque handle identifying the allocation inside the allocator.