Module pool

Module pool 

Memory and resource pool for recording command buffers.

A command pool holds and manages the memory of one or more command buffers. If you destroy a command pool, all command buffers recorded from it become invalid. This could lead to invalid usage and unsoundness, so to ensure safety you must use a command buffer allocator.

Structs

CommandBufferAllocateInfo
Parameters to allocate a CommandPoolAlloc.
CommandPool
Represents a Vulkan command pool.
CommandPoolAlloc
Opaque type that represents a command buffer allocated from a pool.
CommandPoolCreateFlags
Additional properties of the command pool.
CommandPoolCreateInfo
Parameters to create an CommandPool.
CommandPoolResetFlags
Additional properties of the command pool reset operation.