pub struct BufferCopy {
pub src_offset: DeviceSize,
pub dst_offset: DeviceSize,
pub size: DeviceSize,
pub _ne: NonExhaustive,
}Expand description
A region of data to copy between buffers.
Fields
src_offset: DeviceSizeThe offset in bytes or elements from the start of src_buffer that copying will
start from.
The default value is 0.
dst_offset: DeviceSizeThe offset in bytes or elements from the start of dst_buffer that copying will
start from.
The default value is 0.
size: DeviceSizeThe number of bytes or elements to copy.
The default value is 0, which must be overridden.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for BufferCopy
impl Clone for BufferCopy
Sourcefn clone(&self) -> BufferCopy
fn clone(&self) -> BufferCopy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BufferCopy
impl Debug for BufferCopy