pub struct ClearColorImageInfo {
pub image: Arc<Image>,
pub image_layout: ImageLayout,
pub clear_value: ClearColorValue,
pub regions: SmallVec<[ImageSubresourceRange; 1]>,
pub _ne: NonExhaustive,
}Expand description
Parameters to clear a color image.
Fields
image: Arc<Image>The image to clear.
There is no default value.
image_layout: ImageLayoutThe layout used for image during the clear operation.
The following layouts are allowed:
The default value is ImageLayout::TransferDstOptimal.
clear_value: ClearColorValueThe color value to clear the image to.
The default value is ClearColorValue::Float([0.0; 4]).
regions: SmallVec<[ImageSubresourceRange; 1]>The subresource ranges of image to clear.
The default value is a single region, covering the whole image.
_ne: NonExhaustiveImplementations