CopyImageInfo

Struct CopyImageInfo 

pub struct CopyImageInfo {
    pub src_image: Arc<Image>,
    pub src_image_layout: ImageLayout,
    pub dst_image: Arc<Image>,
    pub dst_image_layout: ImageLayout,
    pub regions: SmallVec<[ImageCopy; 1]>,
    pub _ne: NonExhaustive,
}
Parameters to copy data from an image to another image.

Fields

src_image: Arc<Image>

The image to copy from.

There is no default value.

src_image_layout: ImageLayout

The layout used for src_image during the copy operation.

The following layouts are allowed:

The default value is ImageLayout::TransferSrcOptimal.

dst_image: Arc<Image>

The image to copy to.

There is no default value.

dst_image_layout: ImageLayout

The layout used for dst_image during the copy operation.

The following layouts are allowed:

The default value is ImageLayout::TransferDstOptimal.

regions: SmallVec<[ImageCopy; 1]>

The regions of both images to copy between.

The default value is a single region, covering the first mip level, and the smallest of the array layers and extent of the two images. All aspects of each image are selected, or plane0 if the image is multi-planar.

_ne: NonExhaustive

Implementations

Source

impl CopyImageInfo

pub fn images(src_image: Arc<Image>, dst_image: Arc<Image>) -> Self

Returns a CopyImageInfo with the specified src_image and dst_image.