RawDescriptorSet

Struct RawDescriptorSet 

pub struct RawDescriptorSet { /* private fields */ }
A raw descriptor set corresponding directly to a VkDescriptorSet.

This descriptor set does not keep track of synchronization, nor does it store any information on what resources have been written to each descriptor.

Implementations

Source

impl RawDescriptorSet

pub fn new( allocator: Arc<dyn DescriptorSetAllocator>, layout: &Arc<DescriptorSetLayout>, variable_descriptor_count: u32, ) -> Result<RawDescriptorSet, Validated<VulkanError>>

Allocates a new descriptor set and returns it.

pub fn alloc(&self) -> &DescriptorSetAlloc

Returns the allocation of this descriptor set.

pub fn pool(&self) -> &DescriptorPool

Returns the descriptor pool that the descriptor set was allocated from.

pub fn layout(&self) -> &Arc<DescriptorSetLayout>

Returns the layout of this descriptor set.

pub fn variable_descriptor_count(&self) -> u32

Returns the variable descriptor count that this descriptor set was allocated with.

pub unsafe fn update( &self, descriptor_writes: &[WriteDescriptorSet], descriptor_copies: &[CopyDescriptorSet], ) -> Result<(), Box<ValidationError>>

Updates the descriptor set with new values.

Safety
  • The resources in descriptor_writes and descriptor_copies must be kept alive for as long as self is in use.
  • The descriptor set must not be in use by the device, or be recorded to a command buffer as part of a bind command.
  • Host access to the descriptor set must be externally synchronized.