#[non_exhaustive]pub struct PhysicalDeviceGroupProperties {
pub physical_devices: Vec<Arc<PhysicalDevice>>,
pub subset_allocation: bool,
}Expand description
Properties of a group of physical devices that can be used to create a single logical device.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.physical_devices: Vec<Arc<PhysicalDevice>>The physical devices that make up the group.
A physical device can belong to at most one group, but a group can consist of a single physical device.
subset_allocation: boolWhether memory can be allocated from a subset of the devices in the group, rather than only from the group as a whole.
If the length of physical_devices is 1, then this is always false.