pub unsafe trait DeviceOwned {
// Required method
fn device(&self) -> &Arc<Device>;
}Expand description
Implemented on objects that belong to a Vulkan device.
Safety
device()must return the correct device.
pub unsafe trait DeviceOwned {
// Required method
fn device(&self) -> &Arc<Device>;
}Implemented on objects that belong to a Vulkan device.
device() must return the correct device.