#[non_exhaustive]pub struct DisplayPlaneProperties {
pub current_display: Option<Arc<Display>>,
pub current_stack_index: u32,
}Expand description
The properties of a display plane.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.current_display: Option<Arc<Display>>The display that the display plane is currently associated with.
current_stack_index: u32The current z-order of the plane. This will always be less than the total number of planes.