Enum vulkano::framebuffer::FramebufferCreationError
[−]
[src]
pub enum FramebufferCreationError {
OomError(OomError),
DimensionsTooLarge,
AttachmentDimensionsIncompatible {
expected: [u32; 3],
obtained: [u32; 3],
},
AttachmentsCountMismatch {
expected: usize,
obtained: usize,
},
IncompatibleAttachment(IncompatibleRenderPassAttachmentError),
CantDetermineDimensions,
}Error that can happen when creating a framebuffer object.
Variants
OomError(OomError)Out of memory.
DimensionsTooLargeThe requested dimensions exceed the device's limits.
AttachmentDimensionsIncompatibleThe attachment has a size that isn't compatible with the requested framebuffer dimensions.
Fields of AttachmentDimensionsIncompatible
expected: [u32; 3] | Expected dimensions. |
obtained: [u32; 3] | Attachment dimensions. |
AttachmentsCountMismatchThe number of attachments doesn't match the number expected by the render pass.
Fields of AttachmentsCountMismatch
expected: usize | Expected number of attachments. |
obtained: usize | Number of attachments that were given. |
IncompatibleAttachment(IncompatibleRenderPassAttachmentError)One of the images cannot be used as the requested attachment.
CantDetermineDimensionsThe framebuffer has no attachment and no dimension was specified.