pub struct ImageAspects(/* private fields */);Expand description
A set of ImageAspect values.
Implementations
Sourceimpl ImageAspects
impl ImageAspects
Sourcepub const COLOR: Self
pub const COLOR: Self
The single aspect of images with a color format, or the combined aspect of all planes of images with a multi-planar format.
Sourcepub const DEPTH: Self
pub const DEPTH: Self
The single aspect of images with a depth format, or one of the two aspects of images with a combined depth/stencil format.
Sourcepub const STENCIL: Self
pub const STENCIL: Self
The single aspect of images with a stencil format, or one of the two aspects of images with a combined depth/stencil format.
Sourcepub const METADATA: Self
pub const METADATA: Self
An aspect used with sparse memory on some implementations, to hold implementation-defined metadata of an image.
Sourcepub const PLANE_0: Self
pub const PLANE_0: Self
The first plane of an image with a multi-planar format, holding the green color component.
Sourcepub const PLANE_1: Self
pub const PLANE_1: Self
The second plane of an image with a multi-planar format, holding the blue color component if the format has three planes, and a combination of blue and red if the format has two planes.
Sourcepub const PLANE_2: Self
pub const PLANE_2: Self
The third plane of an image with a multi-planar format, holding the red color component.
Sourcepub const MEMORY_PLANE_0: Self
pub const MEMORY_PLANE_0: Self
The first memory plane of images created through the ext_image_drm_format_modifier
extension.
Sourcepub const MEMORY_PLANE_1: Self
pub const MEMORY_PLANE_1: Self
The second memory plane of images created through the ext_image_drm_format_modifier
extension.
Sourcepub const MEMORY_PLANE_2: Self
pub const MEMORY_PLANE_2: Self
The third memory plane of images created through the ext_image_drm_format_modifier
extension.
Sourcepub const MEMORY_PLANE_3: Self
pub const MEMORY_PLANE_3: Self
The fourth memory plane of images created through the ext_image_drm_format_modifier
extension.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the flags that are set in self or other, but not in both.
Sourcepub fn contains_enum(self, val: ImageAspect) -> bool
pub fn contains_enum(self, val: ImageAspect) -> bool
Returns whether self contains the flag corresponding to val.