Module vulkano::instance::loader
[−]
[src]
Vulkan implementation loading system.
Before vulkano can do anything, it first needs to find an implementation of Vulkan. A Vulkan
implementation is defined as a single vkGetInstanceProcAddr function, which can be accessed
through the Loader trait.
This module provides various implementations of the Loader trait.
Once you have a struct that implements Loader, you can create a FunctionPointers struct
from it and use this FunctionPointers struct to build an Instance.
By default vulkano will use the auto_loader() function, which tries to automatically load
a Vulkan implementation from the system.
Structs
| DynamicLibraryLoader |
Implementation of |
| FunctionPointers |
Wraps around a loader and contains function pointers. |
Enums
| LoadingError |
Error that can happen when loading the Vulkan loader. |
Traits
| Loader |
Implemented on objects that grant access to a Vulkan implementation. |
Functions
| auto_loader |
Returns the default |