pub struct MappedMemoryRange {
pub offset: DeviceSize,
pub size: DeviceSize,
pub _ne: NonExhaustive,
}Expand description
Represents a range of host-mapped DeviceMemory to be invalidated or flushed.
Must be contained within the currently mapped range of the device memory.
Fields
offset: DeviceSizeThe offset (in bytes) from the beginning of the allocation, where the range starts.
Must be a multiple of the non_coherent_atom_size device property.
The default value is 0.
size: DeviceSizeThe size (in bytes) of the range.
Must be a multiple of the non_coherent_atom_size device property, or be equal to the
allocation size minus offset.
The default value is 0.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Debug for MappedMemoryRange
impl Debug for MappedMemoryRange