#[non_exhaustive]#[repr(i32)]pub enum LineRasterizationMode {
Default = 0,
Rectangular = 1,
Bresenham = 2,
RectangularSmooth = 3,
}Expand description
The rasterization mode to use for lines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Default = 0
If the strict_lines device property is true,
then this is the same as Rectangular. Otherwise, lines are drawn as parallelograms.
If RasterizationState::line_stipple is Some, then the
strict_lines property must be true and the
stippled_rectangular_lines feature
must be enabled on the device.
Rectangular = 1
Lines are drawn as if they were rectangles extruded from the line.
The rectangular_lines feature must be
enabled on the device. If RasterizationState::line_stipple is Some, then the
stippled_rectangular_lines must
also be enabled.
Bresenham = 2
Lines are drawn by determining which pixel diamonds the line intersects and exits.
The bresenham_lines feature must be
enabled on the device. If RasterizationState::line_stipple is Some, then the
stippled_bresenham_lines must
also be enabled.
RectangularSmooth = 3
As Rectangular, but with alpha falloff.
The smooth_lines feature must be
enabled on the device. If RasterizationState::line_stipple is Some, then the
stippled_smooth_lines must
also be enabled.