pub struct CompositeAlphas(/* private fields */);Expand description
A set of CompositeAlpha values.
Implementations
Sourceimpl CompositeAlphas
impl CompositeAlphas
Sourcepub const OPAQUE: Self
pub const OPAQUE: Self
The alpha channel of the image is ignored. All the pixels are considered as if they have a value of 1.0.
Sourcepub const PRE_MULTIPLIED: Self
pub const PRE_MULTIPLIED: Self
The alpha channel of the image is respected. The color channels are expected to have already been multiplied by the alpha value.
Sourcepub const POST_MULTIPLIED: Self
pub const POST_MULTIPLIED: Self
The alpha channel of the image is respected. The color channels will be multiplied by the alpha value by the compositor before being added to what is behind.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the flags that are set in self or other, but not in both.
Sourcepub fn contains_enum(self, val: CompositeAlpha) -> bool
pub fn contains_enum(self, val: CompositeAlpha) -> bool
Returns whether self contains the flag corresponding to val.