pub struct PresentScalingFlags(/* private fields */);Expand description
A set of PresentScaling values.
Implementations
Sourceimpl PresentScalingFlags
impl PresentScalingFlags
Sourcepub const ONE_TO_ONE: Self
pub const ONE_TO_ONE: Self
No scaling is performed; one swapchain image pixel maps to one surface pixel.
Sourcepub const ASPECT_RATIO_STRETCH: Self
pub const ASPECT_RATIO_STRETCH: Self
Both axes of the image are scaled equally, without changing the aspect ratio of the image, to the largest size in which both axes fit inside the surface.
Sourcepub const STRETCH: Self
pub const STRETCH: Self
Each axis of the image is scaled independently to fit the surface, which may change the aspect ratio of the image.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the flags that are set in self or other, but not in both.
Sourcepub fn contains_enum(self, val: PresentScaling) -> bool
pub fn contains_enum(self, val: PresentScaling) -> bool
Returns whether self contains the flag corresponding to val.