pub enum SharingMode {
Exclusive,
Concurrent(Vec<u32>),
}Expand description
Declares in which queue(s) a resource can be used.
When you create a buffer or an image, you have to tell the Vulkan library in which queue families it will be used. The vulkano library requires you to tell in which queue family the resource will be used, even for exclusive mode.
Variants
Exclusive
The resource is used is only one queue family.
Concurrent(Vec<u32>)
The resource is used in multiple queue families. Can be slower than Exclusive.