pub struct ExternalSemaphoreHandleTypes(/* private fields */);Expand description
A set of ExternalSemaphoreHandleType values.
Implementations
Sourceimpl ExternalSemaphoreHandleTypes
impl ExternalSemaphoreHandleTypes
Sourcepub const OPAQUE_FD: Self
pub const OPAQUE_FD: Self
A POSIX file descriptor handle that is only usable with Vulkan and compatible APIs.
This handle type has reference transference.
Sourcepub const OPAQUE_WIN32: Self
pub const OPAQUE_WIN32: Self
A Windows NT handle that is only usable with Vulkan and compatible APIs.
This handle type has reference transference.
Sourcepub const OPAQUE_WIN32_KMT: Self
pub const OPAQUE_WIN32_KMT: Self
A Windows global share handle that is only usable with Vulkan and compatible APIs.
This handle type has reference transference.
Sourcepub const D3D12_FENCE: Self
pub const D3D12_FENCE: Self
A Windows NT handle that refers to a Direct3D 11 or 12 fence.
This handle type has reference transference.
Sourcepub const SYNC_FD: Self
pub const SYNC_FD: Self
A POSIX file descriptor handle to a Linux Sync File or Android Fence object.
This handle type has copy transference.
Sourcepub const ZIRCON_EVENT: Self
pub const ZIRCON_EVENT: Self
A handle to a Zircon event object.
This handle type has reference transference.
The fuchsia_external_semaphore extension must be enabled on the device.
Sourcepub const fn empty() -> Self
pub const fn empty() -> Self
Returns a ExternalSemaphoreHandleTypes with none of the flags set.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the flags that are set in self or other, but not in both.
Sourcepub fn contains_enum(self, val: ExternalSemaphoreHandleType) -> bool
pub fn contains_enum(self, val: ExternalSemaphoreHandleType) -> bool
Returns whether self contains the flag corresponding to val.