pub struct ImageMemoryBarrier {
pub src_stages: PipelineStages,
pub src_access: AccessFlags,
pub dst_stages: PipelineStages,
pub dst_access: AccessFlags,
pub old_layout: ImageLayout,
pub new_layout: ImageLayout,
pub queue_family_ownership_transfer: Option<QueueFamilyOwnershipTransfer>,
pub image: Arc<Image>,
pub subresource_range: ImageSubresourceRange,
pub _ne: NonExhaustive,
}Expand description
A memory barrier that is applied to a single image.
Fields
src_stages: PipelineStagesThe pipeline stages in the source scope to wait for.
The default value is PipelineStages::empty().
src_access: AccessFlagsThe memory accesses in the source scope to make available and visible.
The default value is AccessFlags::empty().
dst_stages: PipelineStagesThe pipeline stages in the destination scope that must wait for src_stages.
The default value is PipelineStages::empty().
dst_access: AccessFlagsThe memory accesses in the destination scope that must wait for src_access to be made
available and visible.
old_layout: ImageLayoutThe layout that the specified subresource_range of image is expected to be in when the
source scope completes.
new_layout: ImageLayoutThe layout that the specified subresource_range of image will be transitioned to before
the destination scope begins.
queue_family_ownership_transfer: Option<QueueFamilyOwnershipTransfer>For resources created with Sharing::Exclusive, transfers
ownership of a resource from one queue family to another.
image: Arc<Image>The image to apply the barrier to.
subresource_range: ImageSubresourceRangeThe subresource range of image to apply the barrier to.
_ne: NonExhaustiveImplementations