pub struct MemoryBarrier {
pub src_stages: PipelineStages,
pub src_access: AccessFlags,
pub dst_stages: PipelineStages,
pub dst_access: AccessFlags,
pub _ne: NonExhaustive,
}Expand description
A memory barrier that is applied globally.
Fields
src_stages: PipelineStagesThe pipeline stages in the source scope to wait for.
The default value is PipelineStages::empty().
src_access: AccessFlagsThe memory accesses in the source scope to make available and visible.
The default value is AccessFlags::empty().
dst_stages: PipelineStagesThe pipeline stages in the destination scope that must wait for src_stages.
The default value is PipelineStages::empty().
dst_access: AccessFlagsThe memory accesses in the destination scope that must wait for src_access to be made
available and visible.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for MemoryBarrier
impl Clone for MemoryBarrier
Sourcefn clone(&self) -> MemoryBarrier
fn clone(&self) -> MemoryBarrier
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemoryBarrier
impl Debug for MemoryBarrier