[][src]Struct vulkano::buffer::cpu_access::CpuAccessibleBuffer

pub struct CpuAccessibleBuffer<T: ?Sized, A = PotentialDedicatedAllocation<StdMemoryPoolAlloc>> { /* fields omitted */ }

Buffer whose content is accessible by the CPU.

Methods

impl<T> CpuAccessibleBuffer<T>
[src]

Builds a new buffer with some data in it. Only allowed for sized data.

Builds a new uninitialized buffer. Only allowed for sized data.

impl<T> CpuAccessibleBuffer<[T]>
[src]

Builds a new buffer that contains an array T. The initial data comes from an iterator that produces that list of Ts.

Builds a new buffer. Can be used for arrays.

impl<T: ?Sized> CpuAccessibleBuffer<T>
[src]

Builds a new buffer without checking the size.

Safety

You must ensure that the size that you pass is correct for T.

impl<T: ?Sized, A> CpuAccessibleBuffer<T, A>
[src]

Returns the queue families this buffer can be used on.

impl<T: ?Sized, A> CpuAccessibleBuffer<T, A> where
    T: Content + 'static,
    A: MemoryPoolAlloc
[src]

Locks the buffer in order to read its content from the CPU.

If the buffer is currently used in exclusive mode by the GPU, this function will return an error. Similarly if you called write() on the buffer and haven't dropped the lock, this function will return an error as well.

After this function successfully locks the buffer, any attempt to submit a command buffer that uses it in exclusive mode will fail. You can still submit this buffer for non-exclusive accesses (ie. reads).

Locks the buffer in order to write its content from the CPU.

If the buffer is currently in use by the GPU, this function will return an error. Similarly if you called read() on the buffer and haven't dropped the lock, this function will return an error as well.

After this function successfully locks the buffer, any attempt to submit a command buffer that uses it and any attempt to call read() will return an error.