Traits and types for managing the allocation of command buffers and command pools.
In Vulkano, creating a command buffer requires passing an implementation of the
CommandBufferAllocator trait. You can implement this trait yourself, or use the
Vulkano-provided StandardCommandBufferAllocator.
Structs
- Allocation
Handle - An opaque handle identifying an allocation inside an allocator.
- Command
Buffer Alloc - An allocation made using a command buffer allocator.
- Standard
Command Buffer Allocator - Standard implementation of a command buffer allocator.
- Standard
Command Buffer Allocator Create Info - Parameters to create a new
StandardCommandBufferAllocator.
Enums
- Reset
Command Pool Error - Error that can be returned when resetting a
CommandPool.
Traits
- Command
Buffer Allocator - Types that manage the memory of command buffers.