pub struct RenderingAttachmentInfo {
pub image_view: Arc<ImageView>,
pub image_layout: ImageLayout,
pub resolve_info: Option<RenderingAttachmentResolveInfo>,
pub load_op: AttachmentLoadOp,
pub store_op: AttachmentStoreOp,
pub clear_value: Option<ClearValue>,
pub _ne: NonExhaustive,
}Expand description
Parameters to specify properties of an attachment.
Fields
image_view: Arc<ImageView>The image view to use as the attachment.
There is no default value.
image_layout: ImageLayoutThe image layout that image_view should be in during rendering.
The default value is ImageLayout::ColorAttachmentOptimal if image_view has a color
format, ImageLayout::DepthStencilAttachmentOptimal if image_view has a depth/stencil
format.
resolve_info: Option<RenderingAttachmentResolveInfo>The resolve operation that should be performed at the end of rendering.
The default value is None.
load_op: AttachmentLoadOpWhat the implementation should do with the attachment at the start of rendering.
The default value is AttachmentLoadOp::DontCare.
store_op: AttachmentStoreOpWhat the implementation should do with the attachment at the end of rendering.
The default value is AttachmentStoreOp::DontCare.
clear_value: Option<ClearValue>If load_op is AttachmentLoadOp::Clear,
specifies the clear value that should be used for the attachment.
If load_op is something else, provide None.
The default value is None.
_ne: NonExhaustiveImplementations
Sourceimpl RenderingAttachmentInfo
impl RenderingAttachmentInfo
Sourcepub fn image_view(image_view: Arc<ImageView>) -> Self
pub fn image_view(image_view: Arc<ImageView>) -> Self
Returns a RenderingAttachmentInfo with the specified image_view.