pub struct SparseImageOpaqueMemoryBind {
pub offset: DeviceSize,
pub size: DeviceSize,
pub memory: Option<(Arc<DeviceMemory>, DeviceSize)>,
pub metadata: bool,
pub _ne: NonExhaustive,
}Expand description
Parameters for a single sparse bind operation on parts of an image with an opaque memory layout.
This type of sparse bind should be used for mip tail regions, the metadata aspect, and for the
normal regions of images that do not have the SPARSE_RESIDENCY flag set.
Fields
offset: DeviceSizeThe offset in bytes from the start of the image’s memory, where memory is to be (un)bound.
The default value is 0.
size: DeviceSizeThe size in bytes of the memory to be (un)bound.
The default value is 0, which must be overridden.
memory: Option<(Arc<DeviceMemory>, DeviceSize)>If Some, specifies the memory and an offset into that memory that is to be bound.
The provided memory must match the image’s memory requirements.
If None, specifies that existing memory at the specified location is to be unbound.
The default value is None.
metadata: boolSets whether the binding should apply to the metadata aspect of the image, or to the normal texel data.
The default value is false.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for SparseImageOpaqueMemoryBind
impl Clone for SparseImageOpaqueMemoryBind
Sourcefn clone(&self) -> SparseImageOpaqueMemoryBind
fn clone(&self) -> SparseImageOpaqueMemoryBind
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more